@@ -5,11 +5,13 @@ import math
 import re
 import struct
 import types
+import warnings
 from functools import lru_cache
 from importlib import metadata
 from urllib.request import pathname2url
 
 import numpy as np
+import yaml
 
 # The standard library importlib.metadata returns duplicate entrypoints
 # for all python versions up to and including 3.11
@@ -19,25 +21,26 @@ import numpy as np
 from importlib_metadata import packages_distributions
 from packaging.version import Version
 
-from . import constants
+from . import constants, exceptions
 
 # We're importing our own copy of urllib.parse because
 # we need to patch it to support asdf:// URIs, but it'd
 # be irresponsible to do this for all users of a
 # standard library.
 urllib_parse_spec = importlib.util.find_spec("urllib.parse")
-patched_urllib_parse = importlib.util.module_from_spec(urllib_parse_spec)
-urllib_parse_spec.loader.exec_module(patched_urllib_parse)
+_patched_urllib_parse = importlib.util.module_from_spec(urllib_parse_spec)
+urllib_parse_spec.loader.exec_module(_patched_urllib_parse)
 del urllib_parse_spec
 
 # urllib.parse needs to know that it should treat asdf://
 # URIs like http:// URIs for the purposes of joining
 # a relative path to a base URI.
-patched_urllib_parse.uses_relative.append("asdf")
-patched_urllib_parse.uses_netloc.append("asdf")
+_patched_urllib_parse.uses_relative.append("asdf")
+_patched_urllib_parse.uses_netloc.append("asdf")
 
 
 __all__ = [
+    "load_yaml",
     "human_list",
     "get_array_base",
     "get_base_uri",
@@ -49,9 +52,55 @@ __all__ = [
     "is_primitive",
     "uri_match",
     "get_class_name",
+    "get_file_type",
+    "FileType",
 ]
 
 
+def load_yaml(init, tagged=False):
+    """
+    Load just the yaml portion of an ASDF file
+
+    Parameters
+    ----------
+
+    init : filename or file-like
+        If file-like this must be opened in binary mode.
+
+    tagged: bool, optional
+        Return tree with instances of `asdf.tagged.Tagged` this
+        can be helpful if the yaml tags are of interest.
+        If False, the tree will only contain basic python types
+        (see the pyyaml ``BaseLoader`` documentation).
+
+    Returns
+    -------
+
+    tree : dict
+        Dictionary representing the ASDF tree
+    """
+
+    from .generic_io import get_file
+    from .yamlutil import AsdfLoader
+
+    if tagged:
+        loader = AsdfLoader
+    else:
+        loader = yaml.CBaseLoader if getattr(yaml, "__with_libyaml__", None) else yaml.BaseLoader
+
+    with get_file(init, "r") as gf:
+        reader = gf.reader_until(
+            constants.YAML_END_MARKER_REGEX,
+            7,
+            "End of YAML marker",
+            include=True,
+        )
+        # The following call to yaml.load is safe because we're
+        # using only loaders that don't create custom python objects
+        content = yaml.load(reader, Loader=loader)  # noqa: S506
+    return content
+
+
 def human_list(line, separator="and"):
     """
     Formats a list for human readability.
@@ -71,9 +120,10 @@ def human_list(line, separator="and"):
 
     Examples
     --------
-    >>> human_list(["vanilla", "strawberry", "chocolate"], "or")
+    >>> human_list(["vanilla", "strawberry", "chocolate"], "or")  # doctest: +SKIP
     'vanilla, strawberry or chocolate'
     """
+    warnings.warn("asdf.util.human_list is deprecated", exceptions.AsdfDeprecationWarning)
     if len(line) == 1:
         return line[0]
 
@@ -97,24 +147,32 @@ def get_base_uri(uri):
     """
     For a given URI, return the part without any fragment.
     """
-    parts = patched_urllib_parse.urlparse(uri)
-    return patched_urllib_parse.urlunparse([*list(parts[:5]), ""])
+    parts = _patched_urllib_parse.urlparse(uri)
+    return _patched_urllib_parse.urlunparse([*list(parts[:5]), ""])
 
 
 def filepath_to_url(path):
     """
     For a given local file path, return a file:// url.
     """
-    return patched_urllib_parse.urljoin("file:", pathname2url(path))
+    return _patched_urllib_parse.urljoin("file:", pathname2url(path))
+
+
+def _iter_subclasses(cls):
+    """
+    Returns all subclasses of a class.
+    """
+    for x in cls.__subclasses__():
+        yield x
+        yield from _iter_subclasses(x)
 
 
 def iter_subclasses(cls):
     """
     Returns all subclasses of a class.
     """
-    for x in cls.__subclasses__():
-        yield x
-        yield from iter_subclasses(x)
+    warnings.warn("asdf.util.iter_subclasses is deprecated", exceptions.AsdfDeprecationWarning)
+    yield from _iter_subclasses(cls)
 
 
 def calculate_padding(content_size, pad_blocks, block_size):
@@ -151,7 +209,7 @@ def calculate_padding(content_size, pad_blocks, block_size):
     return max(new_size - content_size, 0)
 
 
-class BinaryStruct:
+class _BinaryStruct:
     """
     A wrapper around the Python stdlib struct module to define a
     binary struct more like a dictionary than a tuple.
@@ -267,7 +325,7 @@ def resolve_name(name):
     Examples
     --------
 
-    >>> resolve_name('asdf.util.resolve_name')
+    >>> resolve_name('asdf.util.resolve_name')  # doctest: +SKIP
     <function resolve_name at 0x...>
 
     Raises
@@ -276,6 +334,10 @@ def resolve_name(name):
         If the module or named object is not found.
     """
 
+    warnings.warn(
+        "asdf.util.resolve_name is deprecated, see astropy.utils.resolve_name", exceptions.AsdfDeprecationWarning
+    )
+
     # Note: On python 2 these must be str objects and not unicode
     parts = [str(part) for part in name.split(".")]
 
@@ -351,6 +413,8 @@ def minversion(module, version, inclusive=True):
         as opposed to strictly greater than (default: `True`).
     """
 
+    warnings.warn("asdf.util.minversion is deprecated, see astropy.utils.minversion", exceptions.AsdfDeprecationWarning)
+
     if isinstance(module, types.ModuleType):
         module_name = module.__name__
         module_version = getattr(module, "__version__", None)
@@ -358,7 +422,9 @@ def minversion(module, version, inclusive=True):
         module_name = module
         module_version = None
         try:
-            module = resolve_name(module_name)
+            with warnings.catch_warnings():
+                warnings.filterwarnings("ignore", "asdf.util.resolve_name", exceptions.AsdfDeprecationWarning)
+                module = resolve_name(module_name)
         except ImportError:
             return False
     else:
@@ -382,7 +448,7 @@ def minversion(module, version, inclusive=True):
     return Version(module_version) > Version(version)
 
 
-class InheritDocstrings(type):
+class _InheritDocstrings(type):
     """
     This metaclass makes methods of a class automatically have their
     docstrings filled in from the methods they override in the base
@@ -396,8 +462,8 @@ class InheritDocstrings(type):
 
     For example::
 
-        >>> from asdf.util import InheritDocstrings
-        >>> class A(metaclass=InheritDocstrings):
+        >>> from asdf.util import _InheritDocstrings
+        >>> class A(metaclass=_InheritDocstrings):
         ...     def wiggle(self):
         ...         "Wiggle the thingamajig"
         ...         pass
@@ -405,7 +471,7 @@ class InheritDocstrings(type):
         ...     def wiggle(self):
         ...         pass
         >>> B.wiggle.__doc__
-        u'Wiggle the thingamajig'
+        'Wiggle the thingamajig'
     """
 
     def __init__(cls, name, bases, dct):
@@ -449,6 +515,7 @@ def is_primitive(value):
     bool
         True if the value is primitive, False otherwise
     """
+    warnings.warn("asdf.util.is_primitive is deprecated", exceptions.AsdfDeprecationWarning)
     return isinstance(value, (bool, int, float, complex, str)) or value is None
 
 
@@ -496,12 +563,16 @@ def _compile_uri_match_pattern(pattern):
 def get_file_type(fd):
     """
     Determine the file type of an open GenericFile instance.
+
     Parameters
     ----------
-    fd : GenericFile
+
+    fd : ``asdf.generic_io.GenericFile``
+
     Returns
     -------
-    FileType
+
+    `asdf.util.FileType`
     """
     if fd.peek(5) == constants.ASDF_MAGIC:
         return FileType.ASDF
@@ -514,7 +585,7 @@ def get_file_type(fd):
 
 class FileType(enum.Enum):
     """
-    Enum representing file types recognized by asdf.
+    Enum representing if a file is ASDF, FITS or UNKNOWN.
     """
 
     ASDF = 1
